package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.system.domain.StudentLiveOld;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StudentInfoOld;
import com.ruoyi.system.service.IStudentInfoOldService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学生档案历史信息Controller
 * 
 * @author ruoyi
 * @date 2023-07-28
 */
@RestController
@RequestMapping("/student/old")
public class StudentInfoOldController extends BaseController
{
    @Autowired
    private IStudentInfoOldService studentInfoOldService;

    /**
     * 查询学生档案历史信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(StudentInfoOld studentInfoOld)
    {
        List<StudentInfoOld> list = studentInfoOldService.selectStudentInfoOldList(studentInfoOld);
        return getDataTable(list);
    }


    /**
     * 查询学生档案历史信息列表
     */
    @GetMapping("/echarts")
    public AjaxResult echarts(StudentLiveOld studentLiveOld)
    {
        return studentInfoOldService.selectStudentInfoOldListEcharts(studentLiveOld);
    }

    /**
     * 导出学生档案历史信息列表
     */
    @PreAuthorize("@ss.hasPermi('student:old:export')")
    @Log(title = "学生档案历史信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StudentInfoOld studentInfoOld)
    {
        List<StudentInfoOld> list = studentInfoOldService.selectStudentInfoOldList(studentInfoOld);
        ExcelUtil<StudentInfoOld> util = new ExcelUtil<StudentInfoOld>(StudentInfoOld.class);
        util.exportExcel(response, list, "学生档案历史信息数据");
    }

    /**
     * 获取学生档案历史信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('student:old:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(studentInfoOldService.selectStudentInfoOldById(id));
    }

    /**
     * 新增学生档案历史信息
     */
    @PreAuthorize("@ss.hasPermi('student:old:add')")
    @Log(title = "学生档案历史信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StudentInfoOld studentInfoOld)
    {
        return toAjax(studentInfoOldService.insertStudentInfoOld(studentInfoOld));
    }

    /**
     * 修改学生档案历史信息
     */
    @PreAuthorize("@ss.hasPermi('student:old:edit')")
    @Log(title = "学生档案历史信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StudentInfoOld studentInfoOld)
    {
        return toAjax(studentInfoOldService.updateStudentInfoOld(studentInfoOld));
    }

    /**
     * 删除学生档案历史信息
     */
    @PreAuthorize("@ss.hasPermi('student:old:remove')")
    @Log(title = "学生档案历史信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(studentInfoOldService.deleteStudentInfoOldByIds(ids));
    }
}
