package com.ruoyi.web.controller.info;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.StudentLiveOld;
import com.ruoyi.system.service.IStudentLiveOldService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 学生生活历史信息Controller
 * 
 * @author ruoyi
 * @date 2023-08-03
 */
@RestController
@RequestMapping("/live/old")
public class StudentLiveOldController extends BaseController
{
    @Autowired
    private IStudentLiveOldService studentLiveOldService;

    /**
     * 查询学生生活历史信息列表
     */
    @PreAuthorize("@ss.hasPermi('live:old:list')")
    @GetMapping("/list")
    public TableDataInfo list(StudentLiveOld studentLiveOld)
    {
        List<StudentLiveOld> list = studentLiveOldService.selectStudentLiveOldList(studentLiveOld);
        return getDataTable(list);
    }

    /**
     * 导出学生生活历史信息列表
     */
    @PreAuthorize("@ss.hasPermi('live:old:export')")
    @Log(title = "学生生活历史信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StudentLiveOld studentLiveOld)
    {
        List<StudentLiveOld> list = studentLiveOldService.selectStudentLiveOldList(studentLiveOld);
        ExcelUtil<StudentLiveOld> util = new ExcelUtil<StudentLiveOld>(StudentLiveOld.class);
        util.exportExcel(response, list, "学生生活历史信息数据");
    }

    /**
     * 获取学生生活历史信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:old:query')")
    @GetMapping(value = "/{liveId}")
    public AjaxResult getInfo(@PathVariable("liveId") Long liveId)
    {
        return success(studentLiveOldService.selectStudentLiveOldByLiveId(liveId));
    }

    /**
     * 新增学生生活历史信息
     */
    @PreAuthorize("@ss.hasPermi('live:old:add')")
    @Log(title = "学生生活历史信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StudentLiveOld studentLiveOld)
    {
        return toAjax(studentLiveOldService.insertStudentLiveOld(studentLiveOld));
    }

    /**
     * 修改学生生活历史信息
     */
    @PreAuthorize("@ss.hasPermi('live:old:edit')")
    @Log(title = "学生生活历史信息", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody StudentLiveOld studentLiveOld)
    {
        return toAjax(studentLiveOldService.updateStudentLiveOld(studentLiveOld));
    }

    /**
     * 删除学生生活历史信息
     */
    @PreAuthorize("@ss.hasPermi('live:old:remove')")
    @Log(title = "学生生活历史信息", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{liveIds}")
    public AjaxResult remove(@PathVariable Long[] liveIds)
    {
        return toAjax(studentLiveOldService.deleteStudentLiveOldByLiveIds(liveIds));
    }
}
