package com.ruoyi.system.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.utils.ClassUtils;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.StudentInfoOld;
import com.ruoyi.system.domain.StudentLiveOld;
import com.ruoyi.system.domain.StudentMindOld;
import com.ruoyi.system.mapper.StudentInfoOldMapper;
import com.ruoyi.system.mapper.StudentLiveOldMapper;
import com.ruoyi.system.mapper.StudentMindOldMapper;
import lombok.SneakyThrows;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.StudentInfoMapper;
import com.ruoyi.system.domain.StudentInfo;
import com.ruoyi.system.service.IStudentInfoService;

/**
 * 学生档案信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-07-21
 */
@Service
public class StudentInfoServiceImpl implements IStudentInfoService 
{
    @Autowired
    private StudentInfoMapper studentInfoMapper;
    @Autowired
    private StudentInfoOldMapper studentInfoOldMapper;
    @Autowired
    private StudentLiveOldMapper studentLiveOldMapper;
    @Autowired
    private StudentMindOldMapper studentMindOldMapper;

    /**
     * 查询学生档案信息
     * 
     * @param id 学生档案信息主键
     * @return 学生档案信息
     */
    @Override
    public StudentInfo selectStudentInfoById(Long id)
    {
        return studentInfoMapper.selectStudentInfoById(id);
    }

    /**
     * 查询学生档案信息列表
     * 
     * @param studentInfo 学生档案信息
     * @return 学生档案信息
     */
    @Override
    public List<StudentInfo> selectStudentInfoList(StudentInfo studentInfo)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        Map<String, Object> params = studentInfo.getParams();
        String role = "";
        if (params != null && params.size() > 0) {
            role = (String) params.get("role");
        }
        if("parents".equals(role)){
            studentInfo.setParentsId(user.getUserId());
        }
        return studentInfoMapper.selectStudentInfoList(studentInfo);
    }

    /**
     * 新增学生档案信息
     * 
     * @param studentInfo 学生档案信息
     * @return 结果
     */
    @SneakyThrows
    @Override
    public AjaxResult insertStudentInfo(StudentInfo studentInfo)
    {
        //查询数据库是否存在信息
        StudentInfo student = new StudentInfo();
        student.setStudentId(studentInfo.getStudentId());
        List<StudentInfo> studentInfos = studentInfoMapper.selectStudentInfoList(student);
        if(studentInfos!=null && studentInfos.size()>0){
            return AjaxResult.error("该学生已存在，请勿重复添加");
        }
        studentInfo.setCreateTime(DateUtils.getNowDate());
        //新增 心理健康
        StudentMindOld studentMindOld = new StudentMindOld();
        ClassUtils.copyProperties(student, studentMindOld);
        studentMindOld.setCreateTime(DateUtils.getNowDate());
        studentMindOld.setUpdateTime(DateUtils.getNowDate());
        studentMindOldMapper.insertStudentMindOld(studentMindOld);

        //新增 身高体重
        StudentLiveOld studentLiveOld = new StudentLiveOld();
        ClassUtils.copyProperties(student, studentLiveOld);
        studentLiveOld.setCreateTime(DateUtils.getNowDate());
        studentLiveOld.setUpdateTime(DateUtils.getNowDate());
        studentLiveOldMapper.insertStudentLiveOld(studentLiveOld);

        studentInfoMapper.deleteStudentInfoById(studentInfo.getId());
        int rows = studentInfoMapper.insertStudentInfo(studentInfo);
        return rows > 0 ? AjaxResult.success() : AjaxResult.error();

    }

    /**
     * 修改学生档案信息
     * 
     * @param studentInfo 学生档案信息
     * @return 结果
     */
    @SneakyThrows
    @Override
    public int updateStudentInfo(StudentInfo studentInfo)
    {
        //查询修改前数据
        StudentInfo student = studentInfoMapper.selectStudentInfoByStudentId(studentInfo.getStudentId());
        StudentInfoOld studentInfoOld = new StudentInfoOld();
        ClassUtils.copyProperties(student, studentInfoOld);
        studentInfoOld.setCreateTime(DateUtils.getNowDate());
        studentInfoOld.setUpdateTime(studentInfo.getCreateTime());
        studentInfoOldMapper.insertStudentInfoOld(studentInfoOld);
        studentInfo.setId(student.getId());
        studentInfo.setUpdateTime(DateUtils.getNowDate());
        return studentInfoMapper.updateStudentInfo(studentInfo);
    }

    /**
     * 批量删除学生档案信息
     * 
     * @param ids 需要删除的学生档案信息主键
     * @return 结果
     */
    @Override
    public int deleteStudentInfoByIds(Long[] ids)
    {
        return studentInfoMapper.deleteStudentInfoByIds(ids);
    }

    /**
     * 删除学生档案信息信息
     * 
     * @param id 学生档案信息主键
     * @return 结果
     */
    @Override
    public int deleteStudentInfoById(Long id)
    {
        return studentInfoMapper.deleteStudentInfoById(id);
    }

    @Override
    public AjaxResult statistics(StudentInfo studentInfo) {

        if(StringUtils.isEmpty(studentInfo.getClassId())){
            return AjaxResult.error("请选择班级");
        }
        int zs = 0;
        int nan = 0;
        int nv = 0;
        int js = 0;
        int ls = 0;
        int pk = 0;
        Map<String,Object> map = new HashMap<>();
        List<StudentInfo> studentInfoList = studentInfoMapper.selectStudentInfoList(studentInfo);
        if(studentInfoList!=null && studentInfoList.size()>0){
            for (StudentInfo info : studentInfoList) {
                zs++;
                if(StringUtils.isNotEmpty(info.getSex()) && info.getSex().equals("1")){
                    nan++;
                }else{
                    nv++;
                }

                if(StringUtils.isNotEmpty(info.getIsNearsightedness()) && info.getIsNearsightedness().equals("1")){
                    js++;
                }
                if(StringUtils.isNotEmpty(info.getIsLset()) && info.getIsLset().equals("1")){
                    ls++;
                }
                if(StringUtils.isNotEmpty(info.getIsPoverty()) && info.getIsPoverty().equals("1")){
                    pk++;
                }
            }
        }
        map.put("zs",zs);
        map.put("nan",nan);
        map.put("nv",nv);
        map.put("js",js);
        map.put("ls",ls);
        map.put("pk",pk);

        return AjaxResult.success("成功",map);
    }
}
