package com.ruoyi.system.service.impl;

import java.util.*;
import java.util.stream.Collectors;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.FormalTeacherClass;
import com.ruoyi.common.core.domain.entity.vo.SysDeptVo;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.XiakeConfig;
import com.ruoyi.system.domain.XiaoyuanNotice;
import com.ruoyi.system.mapper.XiakeConfigMapper;
import com.ruoyi.system.mapper.XiaoyuanNoticeMapper;
import com.ruoyi.system.service.IFormalTeacherClassService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.SysDept;
import com.ruoyi.common.core.domain.entity.SysRole;
import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.spring.SpringUtils;
import com.ruoyi.system.mapper.SysDeptMapper;
import com.ruoyi.system.mapper.SysRoleMapper;
import com.ruoyi.system.service.ISysDeptService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 部门管理 服务实现
 * 
 * @author ruoyi
 */
@Service
public class SysDeptServiceImpl implements ISysDeptService
{
    @Autowired
    private SysDeptMapper deptMapper;

    @Autowired
    private SysRoleMapper roleMapper;

    @Autowired
    private XiakeConfigMapper configMapper;

    @Autowired
    private IFormalTeacherClassService formalTeacherClassService;

    /**
     * 查询部门管理数据
     * 
     * @param dept 部门信息
     * @return 部门信息集合
     */
    @Override
    //@DataScope(deptAlias = "d")
    public List<SysDept> selectDeptList(SysDept dept)
    {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        if(!"admin".equals(user.getUserName())){
            if(dept.getParentId()==null ||dept.getParentId()==0L){
                dept.setParentId(user.getDeptId());
            }
            dept.setDeptId(user.getDeptId());
            if(user.getDeptId()==null || user.getDeptId() == 0L){
                List<FormalTeacherClass> teacherClass = formalTeacherClassService.getTeacherClass(String.valueOf(user.getUserId()));
                if(dept.getParentId()==null ||dept.getParentId()==0L){
                    dept.setParentId(teacherClass.get(0).getSchoolId());
                }
                dept.setDeptId(teacherClass.get(0).getSchoolId());
            }

        }
        return deptMapper.selectDeptList(dept);
    }

    @Override
    @DataScope(deptAlias = "d")
    public List<SysDept> selectDeptOldList(SysDept dept) {
        SysUser user = SecurityUtils.getLoginUser().getUser();
        if(!"admin".equals(user.getUserName())){
            dept.setParentId(user.getDeptId());
            if(user.getDeptId()==null || user.getDeptId() == 0L){
                List<FormalTeacherClass> teacherClass = formalTeacherClassService.getTeacherClass(String.valueOf(user.getUserId()));
                dept.setParentId(teacherClass.get(0).getSchoolId());
            }

        }
        return deptMapper.selectDeptOldList(dept);
    }

    /**
     * 查询部门树结构信息
     * 
     * @param dept 部门信息
     * @return 部门树信息集合
     */
    @Override
    public List<TreeSelect> selectDeptTreeList(SysDept dept)
    {
        List<SysDept> depts = selectDeptList(dept);
        return buildDeptTreeSelect(depts);
    }

    /**
     * 构建前端所需要树结构
     * 
     * @param depts 部门列表
     * @return 树结构列表
     */
    @Override
    public List<SysDept> buildDeptTree(List<SysDept> depts)
    {
        List<SysDept> returnList = new ArrayList<SysDept>();
        List<Long> tempList = depts.stream().map(SysDept::getDeptId).collect(Collectors.toList());
        for (SysDept dept : depts)
        {
            // 如果是顶级节点, 遍历该父节点的所有子节点
            if (!tempList.contains(dept.getParentId()))
            {
                recursionFn(depts, dept);
                returnList.add(dept);
            }
        }
        if (returnList.isEmpty())
        {
            returnList = depts;
        }
        return returnList;
    }

    /**
     * 构建前端所需要下拉树结构
     * 
     * @param depts 部门列表
     * @return 下拉树结构列表
     */
    @Override
    public List<TreeSelect> buildDeptTreeSelect(List<SysDept> depts)
    {
        List<SysDept> deptTrees = buildDeptTree(depts);
        return deptTrees.stream().map(TreeSelect::new).collect(Collectors.toList());
    }

    /**
     * 根据角色ID查询部门树信息
     * 
     * @param roleId 角色ID
     * @return 选中部门列表
     */
    @Override
    public List<Long> selectDeptListByRoleId(Long roleId)
    {
        SysRole role = roleMapper.selectRoleById(roleId);
        return deptMapper.selectDeptListByRoleId(roleId, role.isDeptCheckStrictly());
    }

    /**
     * 根据部门ID查询信息
     * 
     * @param deptId 部门ID
     * @return 部门信息
     */
    @Override
    public SysDept selectDeptById(Long deptId)
    {
        return deptMapper.selectDeptById(deptId);
    }

    /**
     * 根据ID查询所有子部门（正常状态）
     * 
     * @param deptId 部门ID
     * @return 子部门数
     */
    @Override
    public int selectNormalChildrenDeptById(Long deptId)
    {
        return deptMapper.selectNormalChildrenDeptById(deptId);
    }

    /**
     * 是否存在子节点
     * 
     * @param deptId 部门ID
     * @return 结果
     */
    @Override
    public boolean hasChildByDeptId(Long deptId)
    {
        int result = deptMapper.hasChildByDeptId(deptId);
        return result > 0;
    }

    /**
     * 查询部门是否存在用户
     * 
     * @param deptId 部门ID
     * @return 结果 true 存在 false 不存在
     */
    @Override
    public boolean checkDeptExistUser(Long deptId)
    {
        int result = deptMapper.checkDeptExistUser(deptId);
        return result > 0;
    }

    /**
     * 校验部门名称是否唯一
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    public boolean checkDeptNameUnique(SysDept dept)
    {
        Long deptId = StringUtils.isNull(dept.getDeptId()) ? -1L : dept.getDeptId();
        SysDept info = deptMapper.checkDeptNameUnique(dept.getDeptName(), dept.getParentId());
        if (StringUtils.isNotNull(info) && info.getDeptId().longValue() != deptId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;
    }

    /**
     * 校验部门是否有数据权限
     * 
     * @param deptId 部门id
     */
    @Override
    public void checkDeptDataScope(Long deptId)
    {
        if (!SysUser.isAdmin(SecurityUtils.getUserId()))
        {
            SysDept dept = new SysDept();
            dept.setDeptId(deptId);
            List<SysDept> depts = SpringUtils.getAopProxy(this).selectDeptList(dept);
            if (StringUtils.isEmpty(depts))
            {
                throw new ServiceException("没有权限访问部门数据！");
            }
        }
    }

    /**
     * 新增保存部门信息
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    @Transactional
    public int insertDept(SysDept dept)
    {

        SysDept info = deptMapper.selectDeptById(dept.getParentId());
        int index = 0;
        if(info!=null){
            // 如果父节点不为正常状态,则不允许新增子节点
            if (!UserConstants.DEPT_NORMAL.equals(info.getStatus()))
            {
                throw new ServiceException("部门停用，不允许新增");
            }
            dept.setAncestors(info.getAncestors() + "," + dept.getParentId());
            index = deptMapper.insertDept(dept);
            //往xiake_config插入数据
            XiakeConfig config = new XiakeConfig();
            config.setConfigName("下课时间");
            config.setConfigKey(dept.getDeptId()+":1");
            config.setConfigValue("5");
            config.setConfigType("1");
            config.setCreateTime(DateUtils.getNowDate());
            config.setUpdateTime(DateUtils.getNowDate());
            configMapper.insertConfig(config);
            XiakeConfig config1 = new XiakeConfig();
            config1.setConfigName("延迟下课");
            config1.setConfigKey(dept.getDeptId()+":2");
            config1.setConfigValue("5");
            config.setConfigType("2");
            config1.setCreateTime(DateUtils.getNowDate());
            config1.setUpdateTime(DateUtils.getNowDate());
            configMapper.insertConfig(config1);

        }else{
            dept.setAncestors(String.valueOf(dept.getParentId()));
            index = deptMapper.insertDept(dept);
        }

        return index;
    }

    /**
     * 修改保存部门信息
     * 
     * @param dept 部门信息
     * @return 结果
     */
    @Override
    public int updateDept(SysDept dept)
    {
        SysDept newParentDept = deptMapper.selectDeptById(dept.getParentId());
        SysDept oldDept = deptMapper.selectDeptById(dept.getDeptId());
        if (StringUtils.isNotNull(newParentDept) && StringUtils.isNotNull(oldDept))
        {
            String newAncestors = newParentDept.getAncestors() + "," + newParentDept.getDeptId();
            String oldAncestors = oldDept.getAncestors();
            dept.setAncestors(newAncestors);
            updateDeptChildren(dept.getDeptId(), newAncestors, oldAncestors);
        }
        int result = deptMapper.updateDept(dept);
        if (UserConstants.DEPT_NORMAL.equals(dept.getStatus()) && StringUtils.isNotEmpty(dept.getAncestors())
                && !StringUtils.equals("0", dept.getAncestors()))
        {
            // 如果该部门是启用状态，则启用该部门的所有上级部门
            updateParentDeptStatusNormal(dept);
        }
        return result;
    }

    /**
     * 修改该部门的父级部门状态
     * 
     * @param dept 当前部门
     */
    private void updateParentDeptStatusNormal(SysDept dept)
    {
        String ancestors = dept.getAncestors();
        Long[] deptIds = Convert.toLongArray(ancestors);
        deptMapper.updateDeptStatusNormal(deptIds);
    }

    /**
     * 修改子元素关系
     * 
     * @param deptId 被修改的部门ID
     * @param newAncestors 新的父ID集合
     * @param oldAncestors 旧的父ID集合
     */
    public void updateDeptChildren(Long deptId, String newAncestors, String oldAncestors)
    {
        List<SysDept> children = deptMapper.selectChildrenDeptById(deptId);
        for (SysDept child : children)
        {
            child.setAncestors(child.getAncestors().replaceFirst(oldAncestors, newAncestors));
        }
        if (children.size() > 0)
        {
            deptMapper.updateDeptChildren(children);
        }
    }

    /**
     * 删除部门管理信息
     * 
     * @param deptId 部门ID
     * @return 结果
     */
    @Override
    public int deleteDeptById(Long deptId)
    {
        return deptMapper.deleteDeptById(deptId);
    }

    @Override
    public AjaxResult insertDeptList(SysDeptVo sysDeptVo) {

        List<SysDept>  sysDeptList = sysDeptVo.getSysDeptList();
        if(sysDeptList==null || sysDeptList.size()<=0){
            return AjaxResult.error("参数不能为空");
        }
        //将当前学校的班级部门千不改为禁用
        deptMapper.updateDeptIsStatus(sysDeptList.get(0).getParentId());
        List<Long> deptIds = new ArrayList<>();
        int num = 0;

        for (SysDept sysDept : sysDeptList) {
            if("N".equals(sysDept.getIsAdd())){
                deptIds.add(sysDept.getDeptId());
                num = sysDept.getOrderNum();
            }else{
                //新增
                sysDept.setOrderNum(num+1);
                deptMapper.insertDept(sysDept);

                //往xiake_config插入数据
                XiakeConfig config = new XiakeConfig();
                config.setConfigName("下课时间");
                config.setConfigKey(sysDept.getDeptId()+":1");
                config.setConfigValue("5");
                config.setConfigType("1");
                config.setCreateTime(DateUtils.getNowDate());
                config.setUpdateTime(DateUtils.getNowDate());
                configMapper.insertConfig(config);
                XiakeConfig config1 = new XiakeConfig();
                config1.setConfigName("延迟下课");
                config1.setConfigKey(sysDept.getDeptId()+":2");
                config1.setConfigValue("5");
                config.setConfigType("2");
                config1.setCreateTime(DateUtils.getNowDate());
                config1.setUpdateTime(DateUtils.getNowDate());
                configMapper.insertConfig(config1);

            }
        }
        Long[] skuIds = deptIds.toArray(new Long[deptIds.size()]);
        deptMapper.updateDeptStatusNormal(skuIds);
        return AjaxResult.success("操作成功");
    }

    @Override
    public AjaxResult selectDeptSixList(SysDept dept) {

        Map<String,Object> map = new HashMap<>();
        List<SysDept> sysDeptList = deptMapper.selectDeptList(dept);
        List<SysDept> sysDeptList1 = new ArrayList<>();
        List<SysDept> sysDeptList2 = new ArrayList<>();
        List<SysDept> sysDeptList3 = new ArrayList<>();
        List<SysDept> sysDeptList4 = new ArrayList<>();
        List<SysDept> sysDeptList5 = new ArrayList<>();
        List<SysDept> sysDeptList6 = new ArrayList<>();
        for (SysDept sysDept : sysDeptList) {
            if(sysDept.getDeptName().contains("一年级")){
                sysDeptList1.add(sysDept);
            }else if(sysDept.getDeptName().contains("二年级")){
                sysDeptList2.add(sysDept);
            }else if(sysDept.getDeptName().contains("三年级")){
                sysDeptList3.add(sysDept);
            }else if(sysDept.getDeptName().contains("四年级")){
                sysDeptList4.add(sysDept);
            }else if(sysDept.getDeptName().contains("五年级")){
                sysDeptList5.add(sysDept);
            }else if(sysDept.getDeptName().contains("六年级")){
                sysDeptList6.add(sysDept);
            }
        }
        map.put("one",sysDeptList1);
        map.put("two",sysDeptList2);
        map.put("three",sysDeptList3);
        map.put("four",sysDeptList4);
        map.put("five",sysDeptList5);
        map.put("six",sysDeptList6);
        return AjaxResult.success(map);
    }

    @Override
    public List<SysDept> selectDeptListChildren(Long parentId) {
        return deptMapper.selectDeptListChildren(parentId);
    }



    /**
     * 递归列表
     */
    private void recursionFn(List<SysDept> list, SysDept t)
    {
        // 得到子节点列表
        List<SysDept> childList = getChildList(list, t);
        t.setChildren(childList);
        for (SysDept tChild : childList)
        {
            if (hasChild(list, tChild))
            {
                recursionFn(list, tChild);
            }
        }
    }

    /**
     * 得到子节点列表
     */
    private List<SysDept> getChildList(List<SysDept> list, SysDept t)
    {
        List<SysDept> tlist = new ArrayList<SysDept>();
        Iterator<SysDept> it = list.iterator();
        while (it.hasNext())
        {
            SysDept n = (SysDept) it.next();
            if (StringUtils.isNotNull(n.getParentId()) && n.getParentId().longValue() == t.getDeptId().longValue())
            {
                tlist.add(n);
            }
        }
        return tlist;
    }

    /**
     * 判断是否有子节点
     */
    private boolean hasChild(List<SysDept> list, SysDept t)
    {
        return getChildList(list, t).size() > 0;
    }
}
